@@ -8,11 +8,6 @@ try:
 except ImportError:
     import_errors.append('enums')
 
-try:
-    from fields import *
-except ImportError:
-    import_errors.append('fields')
-
 try:
     from filenames import *
 except ImportError:
